

set -ex



nc-config --all
test -f ${PREFIX}/lib/libnetcdf.a
test -f ${PREFIX}/lib/libnetcdf.dylib
ncdump -h http://geoport-dev.whoi.edu/thredds/dodsC/estofs/atlantic
ncdump -h https://data.nodc.noaa.gov/thredds/dodsC/ioos/sccoos/scripps_pier/scripps_pier-2016.nc
conda inspect linkages -p $PREFIX libnetcdf
conda inspect objects -p $PREFIX libnetcdf
exit 0
